==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolClaimLifetimeFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterPoolClaimLifetimeFluent<A extends ClusterPoolClaimLifetimeFluent<A>> extends BaseFluent<A>{
  public ClusterPoolClaimLifetimeFluent() {
  }
  
  public ClusterPoolClaimLifetimeFluent(ClusterPoolClaimLifetime instance) {
    this.copyInstance(instance);
  }
  private Duration _default;
  private Duration maximum;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterPoolClaimLifetime instance) {
    instance = (instance != null ? instance : new ClusterPoolClaimLifetime());
  
    if (instance != null) {
        this.withDefault(instance.getDefault());
        this.withMaximum(instance.getMaximum());
        this.withDefault(instance.getDefault());
        this.withMaximum(instance.getMaximum());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Duration getDefault() {
    return this._default;
  }
  
  public A withDefault(Duration _default) {
    this._default=_default; return (A) this;
  }
  
  public boolean hasDefault() {
    return this._default != null;
  }
  
  public Duration getMaximum() {
    return this.maximum;
  }
  
  public A withMaximum(Duration maximum) {
    this.maximum=maximum; return (A) this;
  }
  
  public boolean hasMaximum() {
    return this.maximum != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPoolClaimLifetimeFluent that = (ClusterPoolClaimLifetimeFluent) o;
    if (!java.util.Objects.equals(_default, that._default)) return false;
  
    if (!java.util.Objects.equals(maximum, that.maximum)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(_default,  maximum,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (maximum != null) { sb.append("maximum:"); sb.append(maximum + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolClaimLifetimeFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterPoolClaimLifetimeFluent<A extends ClusterPoolClaimLifetimeFluent<A>> extends BaseFluent<A>{
  public ClusterPoolClaimLifetimeFluent() {
  }
  
  public ClusterPoolClaimLifetimeFluent(ClusterPoolClaimLifetime instance) {
    this.copyInstance(instance);
  }
  private Duration _default;
  private Duration maximum;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterPoolClaimLifetime instance) {
    instance = (instance != null ? instance : new ClusterPoolClaimLifetime());
    if (instance != null) {
          this.withDefault(instance.getDefault());
          this.withMaximum(instance.getMaximum());
          this.withDefault(instance.getDefault());
          this.withMaximum(instance.getMaximum());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Duration getDefault() {
    return this._default;
  }
  
  public A withDefault(Duration _default) {
    this._default = _default;
    return (A) this;
  }
  
  public boolean hasDefault() {
    return this._default != null;
  }
  
  public Duration getMaximum() {
    return this.maximum;
  }
  
  public A withMaximum(Duration maximum) {
    this.maximum = maximum;
    return (A) this;
  }
  
  public boolean hasMaximum() {
    return this.maximum != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPoolClaimLifetimeFluent that = (ClusterPoolClaimLifetimeFluent) o;
    if (!java.util.Objects.equals(_default, that._default)) return false;
    if (!java.util.Objects.equals(maximum, that.maximum)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(_default,  maximum,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (maximum != null) { sb.append("maximum:"); sb.append(maximum + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
